@@ -1,6 +1,6 @@
 /*******************************************************************************
  * #-------------------------------------------------------------------------------
- * # Copyright (c) 2003-2016 IPI PAN.
+ * # dmLab 2003-2019
  * # All rights reserved. This program and the accompanying materials
  * # are made available under the terms of the GNU Public License v3.0
  * # which accompanies this distribution, and is available at
@@ -15,11 +15,6 @@
  * # Algorithm 'SLIQ' developed by Mariusz Gromada
  * # R Package developed by Michal Draminski & Julian Zubek
  * #-------------------------------------------------------------------------------
- * # If you want to use dmLab or MCFS/MCFS-ID, please cite the following paper:
- * # M.Draminski, A.Rada-Iglesias, S.Enroth, C.Wadelius, J. Koronacki, J.Komorowski 
- * # "Monte Carlo feature selection for supervised classification", 
- * # BIOINFORMATICS 24(1): 110-117 (2008)
- * #-------------------------------------------------------------------------------
  *******************************************************************************/
 package dmLab.classifier;
 
@@ -34,7 +29,6 @@ import dmLab.mcfs.tree.Tree;
 import dmLab.mcfs.tree.TreeNode;
 import dmLab.utils.list.IntegerList;
 
-
 public abstract class WekaTree extends WekaClassifier
 {
 	protected Tree tree;
@@ -173,7 +167,7 @@ public abstract class WekaTree extends WekaClassifier
 
 					//System.out.println("ADD: "+connStr);
 					existingConnection.add(connStr);	                    
-					connectionsLight.addDependency(parentTmp.condition.attributeName, node.condition.attributeName, connValue);
+					connectionsLight.addID(parentTmp.condition.attributeName, node.condition.attributeName, connValue);
 				}
 				parentTmp = parentTmp.getParent();                   	
 			}            	            
