@@ -1,6 +1,6 @@
 /*******************************************************************************
  * #-------------------------------------------------------------------------------
- * # Copyright (c) 2003-2016 IPI PAN.
+ * # dmLab 2003-2019
  * # All rights reserved. This program and the accompanying materials
  * # are made available under the terms of the GNU Public License v3.0
  * # which accompanies this distribution, and is available at
@@ -15,16 +15,12 @@
  * # Algorithm 'SLIQ' developed by Mariusz Gromada
  * # R Package developed by Michal Draminski & Julian Zubek
  * #-------------------------------------------------------------------------------
- * # If you want to use dmLab or MCFS/MCFS-ID, please cite the following paper:
- * # M.Draminski, A.Rada-Iglesias, S.Enroth, C.Wadelius, J. Koronacki, J.Komorowski 
- * # "Monte Carlo feature selection for supervised classification", 
- * # BIOINFORMATICS 24(1): 110-117 (2008)
- * #-------------------------------------------------------------------------------
  *******************************************************************************/
 package dmLab.gui.mainWindow;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.io.File;
+import java.util.Random;
 
 import javax.swing.BorderFactory;
 import javax.swing.JButton;
@@ -250,7 +246,8 @@ public class MCFSPanel extends JPanel implements ActionListener
     public void startMCFS()
     {
         setMCFSParameters(mcfsParams);
-    	mcfsParams.seed = System.currentTimeMillis();                
+    	//mcfsParams.seed = System.currentTimeMillis();
+    	mcfsParams.seed = (new Random(System.currentTimeMillis())).nextInt();
         System.out.println(mcfsParams.toString());        
     	MCFSExperiment mcfs = new MCFSExperiment(mcfsParams);
 
